# pyMaBoSS

[![Documentation Status](https://readthedocs.org/projects/pymaboss/badge/?version=latest)](http://pymaboss.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/maboss.svg)](https://badge.fury.io/py/maboss)
[![Build Status](https://travis-ci.org/colomoto/pyMaBoSS.svg?branch=master)](https://travis-ci.org/colomoto/pyMaBoSS)
[![Coverage Status](https://coveralls.io/repos/github/colomoto/pyMaBoSS/badge.svg?branch=master)](https://coveralls.io/github/colomoto/pyMaBoSS?branch=master)

Python interface for the MaBoSS software (https://maboss.curie.fr)

## Installation

### With conda

```
conda install -c colomoto pymaboss
```

### With pip

```
pip install maboss
python -m maboss_setup
```

